==> owncloud-10.2.0.zip: owncloud/apps/files_sharing/l10n/th_TH.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "เซิร์ฟเวอร์ไปยังแชร์เซิร์ฟเวอร์ไม่ได้เปิดใช้งานบนเซิร์ฟเวอร์นี้",
    "The mountpoint name contains invalid characters." : "ชื่อจุดเชื่อมต่อมีตัวอักษรที่ไม่ถูกต้อง",
    "Not allowed to create a federated share with the same user server" : "ไม่อนุญาตให้สร้างแชร์ในเครือกับเซิร์ฟเวอร์ที่มีผู้ใช้เดียวกัน",
    "Invalid or untrusted SSL certificate" : "ใบรับรอง SSL ไม่ถูกต้องหรือไม่น่าเชื่อถือ",
    "Could not authenticate to remote share, password might be wrong" : "ไม่สามารถรับรองความถูกต้องจากรีโมทแชร์ บางทีรหัสผ่านอาจจะผิด",
    "Storage not valid" : "การจัดเก็บข้อมูลไม่ถูกต้อง",
    "Couldn't add remote share" : "ไม่สามารถเพิ่มรีโมทแชร์",
    "Shared with you" : "แชร์กับคุณ",
    "Shared with others" : "แชร์กับผู้อื่น",
    "Shared by link" : "แชร์โดยลิงค์",
    "Anonymous upload" : "อัพโหลดแบบไม่ระบุตัวตน",
    "Click to select files or use drag & drop to upload" : "คลิกเพื่อเลือกไฟล์หรือลากไฟล์มาวางเพื่ออัพโหลด",
    "Uploaded files" : "อัพโหลดไฟล์แล้ว",
    "Uploading..." : "กำลังอัพโหลด...",
    "Nothing shared with you yet" : "ยังไม่มีการแชร์ใดๆ กับคุณเลย",
    "Files and folders others share with you will show up here" : "ไฟล์และโฟลเดอร์อื่นๆ ที่ผู้อื่นแชร์กับคุณจะปรากฏขึ้นที่นี่",
    "Nothing shared yet" : "ยังไม่มีการแชร์ใดๆ",
    "Files and folders you share will show up here" : "ไฟล์และโฟลเดอร์ที่คุณแชร์กับผู้อื่นจะปรากฏขึ้นที่นี่",
    "No shared links" : "ไม่มีลิงค์ที่แชร์",
    "Files and folders you share by link will show up here" : "ไฟล์และโฟลเดอร์ที่คุณแชร์โดยลิงค์จะปรากฏขึ้นที่นี่",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "คุณต้องการที่จะเพิ่มรีโมทแชร์ {name} จาก {owner}@{remote}?",
    "Remote share" : "รีโมทแชร์",
    "Remote share password" : "รหัสผ่านรีโมทแชร์",
    "Cancel" : "ยกเลิก",
    "Add remote share" : "เพิ่มรีโมทแชร์",
    "You can upload into this folder" : "คุณสามารถอัพโหลดลงในโฟลเดอร์นี้",
    "No ownCloud installation (7 or higher) found at {remote}" : "ไม่มีการติดตั้ง ownCloud (7 หรือสูงกว่า) พบได้ที่ {remote}",
    "Invalid ownCloud url" : "URL ownCloud ไม่ถูกต้อง",
    "Share" : "แชร์",
    "No expiration date set" : "ไม่กำหนดวันหมดอายุ",
    "Shared by" : "ถูกแชร์โดย",
    "Sharing" : "แชร์ข้อมูล",
    "Share API is disabled" : "แชร์ API ถูกปิดใช้งาน",
    "Wrong share ID, share doesn't exist" : "แชร์ไอดีผิด หรือ ไม่มีแชร์นั้นอยู่",
    "Could not delete share" : "ไม่สามารถลบแชร์",
    "Please specify a file or folder path" : "โปรดระบุเส้นทางของไฟล์หรือโฟลเดอร์",
    "Wrong path, file/folder doesn't exist" : "เส้นทางที่ผิด, ไม่มีไฟล์หรือโฟลเดอร์นั้นอยู่",
    "Cannot remove all permissions" : "ไม่สามารถลบสิทธิ์ทั้งหมด",
    "Please specify a valid user" : "โปรดระบุผู้ใช้ให้ถูกต้อง",
    "Group sharing is disabled by the administrator" : "การแชร์กลุ่มถูกปิดใช้งานโดยผู้ดูแลระบบ",
    "Please specify a valid group" : "โปรดระบุกลุ่มให้ถูกต้อง",
    "Public link sharing is disabled by the administrator" : "แชร์ลิงก์สาธารณะถูกปิดใช้งานโดยผู้ดูแลระบบ",
    "Public upload disabled by the administrator" : "อัพโหลดสาธารณะถูกปิดใช้งานโดยผู้ดูแลระบบ",
    "Public upload is only possible for publicly shared folders" : "อัพโหลดสาธารณะจะทำได้เฉพาะโฟลเดอร์ที่แชร์กับสาธารณะ",
    "Invalid date, date format must be YYYY-MM-DD" : "วันที่ไม่ถูกต้อง รูปแบบวันที่จะต้องเป็น YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "แชร์ %s ล้มเหลวเพราะแบ็กเอนด์ไม่อนุญาตให้แชร์ไฟล์ประเภท %s",
    "Unknown share type" : "ไม่รู้จักประเภทของแชร์",
    "Not a directory" : "ไม่ได้เป็นไดเรกทอรี",
    "Could not lock path" : "ไม่สามารถล็อคเส้นทาง",
    "Can't change permissions for public share links" : "ไม่สามารถเปลี่ยนสิทธิ์สำหรับลิงค์แชร์สาธารณะ",
    "Wrong or no update parameter given" : "ไม่ถูกต้องหรือไม่ได้อัพเดทพารามิเตอร์",
    "Cannot increase permissions" : "ไม่สามารถเพิ่มสิทธิ์",
    "A file or folder has been <strong>shared</strong>" : "เมื่อไฟล์หรือโฟลเดอร์ได้ถูก <strong>แชร์</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "เมื่อไฟล์หรือโฟลเดอร์ถูกแชร์จาก <strong>เซิร์ฟเวอร์อื่นๆ</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "เมื่อไฟล์ที่แชร์หรือโฟลเดอร์สาธารณะถูก <strong>ดาวน์โหลด</strong>",
    "You received a new remote share %2$s from %1$s" : "คุณได้รับ %2$s รีโมทแชร์ใหม่จาก %1$s",
    "You received a new remote share from %s" : "คุณได้รับรีโมทแชร์ใหม่จาก %s",
    "%1$s accepted remote share %2$s" : "%1$s ยอมรับรีโมทแชร์จาก %2$s",
    "%1$s declined remote share %2$s" : "%1$s ปฏิเสธรีโมทแชร์จาก %2$s",
    "%1$s unshared %2$s from you" : "%1$s ไม่ได้แชร์ %2$s จากคุณ",
    "Public shared folder %1$s was downloaded" : "โฟลเดอร์สาธารณะ %1$s ที่แชร์ถูกดาวน์โหลด",
    "Public shared file %1$s was downloaded" : "ไฟล์สาธารณะ %1$s ที่แชร์ถูกดาวน์โหลด",
    "You shared %1$s with %2$s" : "คุณแชร์ %1$s กับ %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s ได้แชร์ %1$s กับ %3$s",
    "You removed the share of %2$s for %1$s" : "คุณได้ลบแชร์ %2$s สำหรับ %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s ได้ลบแชร์ของ %3$s สำหรับ %1$s",
    "You shared %1$s with group %2$s" : "คุณแชร์ %1$s กับกลุ่ม %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s ได้แชร์ %1$s กับกลุ่ม %3$s",
    "You removed the share of group %2$s for %1$s" : "คุณได้ลบแชร์ของกลุ่ม %2$s สำหรับ %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s ได้ลบแชร์ของกลุ่ม %3$s สำหรับ %1$s",
    "%2$s shared %1$s via link" : "%2$s ได้แชร์ %1$s ผ่านลิงค์",
    "You shared %1$s via link" : "คุณแชร์ %1$s ผ่านลิงค์",
    "You removed the public link for %1$s" : "คุณได้ลบลิงค์สาธารณะสำหรับ %1$s",
    "%2$s removed the public link for %1$s" : "%2$s ได้ลบลิงค์สาธารณะสำหรับ %1$s",
    "Your public link for %1$s expired" : "ลิงก์สาธารณะของคุณสำหรับ %1$s หมดอายุ",
    "The public link of %2$s for %1$s expired" : "ลิงค์สาธารณะของ  %2$s สำหรับ %1$s หมดอายุ",
    "%2$s shared %1$s with you" : "%2$s ถูกแชร์ %1$s กับคุณ",
    "%2$s removed the share for %1$s" : "%2$s ได้ลบแชร์สำหรับ %1$s",
    "Downloaded via public link" : "ดาวน์โหลดผ่านลิงค์สาธารณะ",
    "Shared with %2$s" : "แชร์กับ %2$s",
    "Shared with %3$s by %2$s" : "แชร์กับ %3$s โดย %2$s",
    "Removed share for %2$s" : "แชร์สำหรับ %2$s ถูกลบแล้ว",
    "%2$s removed share for %3$s" : "%2$s ได้ลบแชร์สำหรับ %3$s",
    "Shared with group %2$s" : "แชร์กับกลุ่ม %2$s",
    "Shared with group %3$s by %2$s" : "แชร์กับกลุ่ม %3$s โดย %2$s",
    "Removed share of group %2$s" : "แชร์ของกลุ่ม %2$s ถูกลบแล้ว",
    "%2$s removed share of group %3$s" : "%2$s ได้ลบแชร์ของกลุ่ม %3$s",
    "Shared via link by %2$s" : "แชร์ผ่านลิงค์โดย %2$s",
    "Shared via public link" : "แชร์ผ่านลิงค์สาธารณะ",
    "Removed public link" : "ลิงค์สาธารณะถูกลบแล้ว",
    "%2$s removed public link" : "%2$s ได้ลบลิงค์สาธารณะแล้ว",
    "Public link expired" : "ลิงค์สาธารณะหมดอายุแล้ว",
    "Public link of %2$s expired" : "ลิงค์สาธารณะของ %2$s หมดอายุแล้ว",
    "Shared by %2$s" : "แชร์โดย %2$s",
    "Shares" : "แชร์",
    "This share is password-protected" : "นี้แชร์การป้องกันด้วยรหัสผ่าน",
    "The password is wrong. Try again." : "รหัสผ่านที่ไม่ถูกต้อง กรุณาลองอีกครั้ง",
    "Password" : "รหัสผ่าน",
    "No entries found in this folder" : "ไม่พบรายการในโฟลเดอร์นี้",
    "Name" : "ชื่อ",
    "Share time" : "แชร์เวลา",
    "Expiration date" : "วันที่หมดอายุ",
    "Sorry, this link doesn’t seem to work anymore." : "ขออภัยลิงค์นี้ดูเหมือนจะไม่ทำงานอีกต่อไป",
    "Reasons might be:" : "เหตุผลอาจจะ:",
    "the item was removed" : "รายการที่ถูกลบออก",
    "the link expired" : "ลิงค์หมดอายุ",
    "sharing is disabled" : "การแชร์ถูกปิดใช้งาน",
    "For more info, please ask the person who sent this link." : "สำหรับข้อมูลเพิ่มเติมกรุณาสอบถามผู้ที่ส่งลิงค์นี้",
    "%s is publicly shared" : "%s ได้ถูกแชร์สู่สาธารณะแล้ว",
    "Add to your ownCloud" : "เพิ่มลงใน ownCloud ของคุณ",
    "Download" : "ดาวน์โหลด",
    "Download %s" : "ดาวน์โหลด %s",
    "Direct link" : "ลิงค์โดยตรง",
    "No permission to create share" : "ไม่มีสิทธิ์ในการสร้างแชร์",
    "Pending" : "อยู่ระหว่างดำเนินการ",
    "Accept" : "ยอมรับ",
    "Decline" : "ลดลง",
    "Declined" : "ปฏิเสธ",
    "An error occurred while updating share state: {message}" : "เกิดข้อผิดพลาดขณะอัพเดทสถานะสถานะของแชร์: {message}",
    "Accept Share" : "ยอมรับแชร์",
    "Decline Share" : "ปฏิเสธแชร์",
    "Only recipient can change accepted state" : "เฉพาะผู้รับเท่านั้นที่สามารถเปลี่ยนสถานะที่ยอมรับได้",
    "File sharing" : "กำลังแชร์ไฟล์",
    "State" : "สถานะ",
    "The group is blacklisted for sharing" : "กลุ่มถูกขึ้นบัญชีดำสำหรับการแชร์",
    "Files Sharing" : "กำลังแชร์ไฟล์",
    "Exclude groups from receiving shares." : "ยกเว้นกลุ่มที่ได้รับการแชร์",
    "These groups will not receive shares. Members of the group can still send and receive shares outside of the group." : "กลุ่มเหล่านี้จะไม่ได้รับการแชร์ สมาชิกของกลุ่มยังสามารถส่งและรับการแชร์ที่อยู่นอกกลุ่มได้",
    "Public link" : "ลิงก์สาธารณะ",
    "Couldn't send mail to following recipient(s): %s " : "ไม่สามารถส่งจดหมายไปยังผู้รับต่อไปนี้: %s",
    "Group Sharing Blacklist" : "แชร์กลุ่มบัญชีดำ",
    "Exclude groups from receiving shares" : "ยกเว้นกลุ่มจากการแชร์",
    "These groups will not be available to share with. Members of the group are not restricted in initiating shares and can receive shares with other groups they are a member of as usual." : "กลุ่มเหล่านี้จะไม่สามารถแชร์กับสมาชิกของกลุ่มที่ถูกจำกัดไว้ แต่สามารถแชร์กับกลุ่มอื่นๆที่เป็นสมาชิกได้ตามปกติ"
},
"nplurals=1; plural=0;");

==> owncloud-10.4.0.zip: owncloud/apps/files_sharing/l10n/th_TH.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "เซิร์ฟเวอร์ไปยังแชร์เซิร์ฟเวอร์ไม่ได้เปิดใช้งานบนเซิร์ฟเวอร์นี้",
    "The mountpoint name contains invalid characters." : "ชื่อจุดเชื่อมต่อมีตัวอักษรที่ไม่ถูกต้อง",
    "Not allowed to create a federated share with the same user server" : "ไม่อนุญาตให้สร้างแชร์สหพันธ์กับเซิร์ฟเวอร์ที่มีผู้ใช้เดียวกัน",
    "Invalid or untrusted SSL certificate" : "ใบรับรอง SSL ไม่ถูกต้องหรือไม่น่าเชื่อถือ",
    "Could not authenticate to remote share, password might be wrong" : "ไม่สามารถรับรองความถูกต้องจากรีโมทแชร์ บางทีรหัสผ่านอาจจะผิด",
    "Storage not valid" : "การจัดเก็บข้อมูลไม่ถูกต้อง",
    "Couldn't add remote share" : "ไม่สามารถเพิ่มรีโมทแชร์",
    "Shared with you" : "แชร์กับคุณ",
    "Shared with others" : "แชร์กับผู้อื่น",
    "Shared by link" : "แชร์โดยลิงก์",
    "Anonymous upload" : "อัปโหลดแบบไม่ระบุตัวตน",
    "Click to select files or use drag & drop to upload" : "คลิกเพื่อเลือกไฟล์หรือลากไฟล์มาวางเพื่ออัปโหลด",
    "Uploaded files" : "อัปโหลดไฟล์แล้ว",
    "Uploading..." : "กำลังอัปโหลด...",
    "Nothing shared with you yet" : "ยังไม่มีการแชร์ใดๆ กับคุณเลย",
    "Files and folders others share with you will show up here" : "ไฟล์และโฟลเดอร์อื่นๆ ที่ผู้อื่นแชร์กับคุณจะปรากฏขึ้นที่นี่",
    "Nothing shared yet" : "ยังไม่มีการแชร์ใดๆ",
    "Files and folders you share will show up here" : "ไฟล์และโฟลเดอร์ที่คุณแชร์กับผู้อื่นจะปรากฏขึ้นที่นี่",
    "No shared links" : "ไม่มีลิงก์ที่แชร์",
    "Files and folders you share by link will show up here" : "ไฟล์และโฟลเดอร์ที่คุณแชร์โดยลิงก์จะปรากฏขึ้นที่นี่",
    "An error occurred while updating share state: {message}" : "เกิดข้อผิดพลาดขณะอัปเดตสถานะสถานะของแชร์: {message}",
    "Accept Share" : "ยอมรับแชร์",
    "Decline Share" : "ปฏิเสธแชร์",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "คุณต้องการเพิ่มรีโมทแชร์ {name} จาก {owner}@{remote}?",
    "Remote share" : "รีโมทแชร์",
    "Remote share password" : "รหัสผ่านรีโมทแชร์",
    "Cancel" : "ยกเลิก",
    "Add remote share" : "เพิ่มรีโมทแชร์",
    "You can upload into this folder" : "คุณสามารถอัปโหลดลงในโฟลเดอร์นี้",
    "No ownCloud installation (7 or higher) found at {remote}" : "ไม่มีการติดตั้ง ownCloud (7 หรือสูงกว่า) พบได้ที่ {remote}",
    "Invalid ownCloud url" : "URL ownCloud ไม่ถูกต้อง",
    "Share" : "แชร์",
    "No expiration date set" : "ไม่กำหนดวันหมดอายุ",
    "Declined" : "ปฏิเสธ",
    "Pending" : "อยู่ระหว่างดำเนินการ",
    "Shared by" : "ถูกแชร์โดย",
    "Sharing" : "แชร์ข้อมูล",
    "A file or folder has been <strong>shared</strong>" : "เมื่อไฟล์หรือโฟลเดอร์ถูก <strong>แชร์</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "เมื่อไฟล์หรือโฟลเดอร์ถูกแชร์จาก <strong>เซิร์ฟเวอร์อื่นๆ</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "เมื่อไฟล์ที่แชร์หรือโฟลเดอร์สาธารณะถูก <strong>ดาวน์โหลด</strong>",
    "You received a new remote share %2$s from %1$s" : "คุณได้รับ %2$s รีโมทแชร์ใหม่จาก %1$s",
    "You received a new remote share from %s" : "คุณได้รับรีโมทแชร์ใหม่จาก %s",
    "%1$s accepted remote share %2$s" : "%1$s ยอมรับรีโมทแชร์จาก %2$s",
    "%1$s declined remote share %2$s" : "%1$s ปฏิเสธรีโมทแชร์จาก %2$s",
    "%1$s unshared %2$s from you" : "%1$s ไม่ได้แชร์ %2$s จากคุณ",
    "Public shared folder %1$s was downloaded" : "โฟลเดอร์สาธารณะ %1$s ที่แชร์ถูกดาวน์โหลด",
    "Public shared file %1$s was downloaded" : "ไฟล์สาธารณะ %1$s ที่แชร์ถูกดาวน์โหลด",
    "You shared %1$s with %2$s" : "คุณแชร์ %1$s กับ %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s ได้แชร์ %1$s กับ %3$s",
    "You removed the share of %2$s for %1$s" : "คุณได้ลบแชร์ %2$s สำหรับ %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s ได้ลบแชร์ของ %3$s สำหรับ %1$s",
    "You unshared %1$s shared by %2$s from self" : "คุณเลิกแชร์ %1$s ที่แชร์โดย %2$s ",
    "You shared %1$s with group %2$s" : "คุณแชร์ %1$s กับกลุ่ม %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s ได้แชร์ %1$s กับกลุ่ม %3$s",
    "You removed the share of group %2$s for %1$s" : "คุณได้ลบแชร์ของกลุ่ม %2$s สำหรับ %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s ได้ลบแชร์ของกลุ่ม %3$s สำหรับ %1$s",
    "%2$s shared %1$s via link" : "%2$s ได้แชร์ %1$s ผ่านลิงก์",
    "You shared %1$s via link" : "คุณแชร์ %1$s ผ่านลิงก์",
    "You removed the public link for %1$s" : "คุณได้ลบลิงก์สาธารณะสำหรับ %1$s",
    "%2$s removed the public link for %1$s" : "%2$s ได้ลบลิงก์สาธารณะสำหรับ %1$s",
    "Your public link for %1$s expired" : "ลิงก์สาธารณะของคุณสำหรับ %1$s หมดอายุ",
    "The public link of %2$s for %1$s expired" : "ลิงก์สาธารณะของ  %2$s สำหรับ %1$s หมดอายุ",
    "%2$s shared %1$s with you" : "%2$s ถูกแชร์ %1$s กับคุณ",
    "%2$s removed the share for %1$s" : "%2$s ได้ลบแชร์สำหรับ %1$s",
    "Downloaded via public link" : "ดาวน์โหลดผ่านลิงก์สาธารณะ",
    "Shared with %2$s" : "แชร์กับ %2$s",
    "Shared with %3$s by %2$s" : "แชร์กับ %3$s โดย %2$s",
    "Removed share for %2$s" : "แชร์สำหรับ %2$s ถูกลบแล้ว",
    "%2$s removed share for %3$s" : "%2$s ได้ลบแชร์สำหรับ %3$s",
    "Unshared %1$s from self" : "เลิกแชร์ %1$s ของตัวเอง",
    "Shared with group %2$s" : "แชร์กับกลุ่ม %2$s",
    "Shared with group %3$s by %2$s" : "แชร์กับกลุ่ม %3$s โดย %2$s",
    "Removed share of group %2$s" : "แชร์ของกลุ่ม %2$s ถูกลบแล้ว",
    "%2$s removed share of group %3$s" : "%2$s ได้ลบแชร์ของกลุ่ม %3$s",
    "Shared via link by %2$s" : "แชร์ผ่านลิงก์โดย %2$s",
    "Shared via public link" : "แชร์ผ่านลิงก์สาธารณะ",
    "Removed public link" : "ลิงก์สาธารณะถูกลบแล้ว",
    "%2$s removed public link" : "%2$s ได้ลบลิงก์สาธารณะแล้ว",
    "Public link expired" : "ลิงก์สาธารณะหมดอายุแล้ว",
    "Public link of %2$s expired" : "ลิงก์สาธารณะของ %2$s หมดอายุแล้ว",
    "Shared by %2$s" : "แชร์โดย %2$s",
    "Shares" : "แชร์",
    "File sharing" : "กำลังแชร์ไฟล์",
    "Public link" : "ลิงก์สาธารณะ",
    "Couldn't send mail to following recipient(s): %s " : "ไม่สามารถส่งจดหมายไปยังผู้รับต่อไปนี้: %s",
    "Share API is disabled" : "แชร์ API ถูกปิดใช้งาน",
    "Wrong share ID, share doesn't exist" : "แชร์ไอดีผิด หรือ ไม่มีแชร์นั้นอยู่",
    "Could not delete share" : "ไม่สามารถลบแชร์",
    "Please specify a file or folder path" : "โปรดระบุเส้นทางของไฟล์หรือโฟลเดอร์",
    "Wrong path, file/folder doesn't exist" : "เส้นทางที่ผิด, ไม่มีไฟล์หรือโฟลเดอร์นั้นอยู่",
    "Invalid date, date format must be YYYY-MM-DD" : "วันที่ไม่ถูกต้อง รูปแบบวันที่จะต้องเป็น YYYY-MM-DD",
    "Please specify a valid user" : "โปรดระบุผู้ใช้ให้ถูกต้อง",
    "Group sharing is disabled by the administrator" : "การแชร์กลุ่มถูกปิดใช้งานโดยผู้ดูแลระบบ",
    "Please specify a valid group" : "โปรดระบุกลุ่มให้ถูกต้อง",
    "The group is blacklisted for sharing" : "กลุ่มถูกขึ้นบัญชีดำสำหรับการแชร์",
    "Public link sharing is disabled by the administrator" : "แชร์ลิงก์สาธารณะถูกปิดใช้งานโดยผู้ดูแลระบบ",
    "Public upload disabled by the administrator" : "อัปโหลดสาธารณะถูกปิดใช้งานโดยผู้ดูแลระบบ",
    "Public upload is only possible for publicly shared folders" : "อัปโหลดสาธารณะจะทำได้เฉพาะโฟลเดอร์ที่แชร์กับสาธารณะ",
    "Sharing %s failed because the back end does not allow shares from type %s" : "แชร์ %s ล้มเหลวเพราะแบ็กเอนด์ไม่อนุญาตให้แชร์ไฟล์ประเภท %s",
    "Unknown share type" : "ไม่รู้จักประเภทของแชร์",
    "Not a directory" : "ไม่ได้เป็นไดเรกทอรี",
    "Could not lock path" : "ไม่สามารถล็อคเส้นทาง",
    "Could not update share" : "ไม่สามารถอัปเดตการแชร์",
    "Can't change permissions for public share links" : "ไม่สามารถเปลี่ยนสิทธิ์สำหรับลิงก์แชร์สาธารณะ",
    "Only recipient can change accepted state" : "เฉพาะผู้รับเท่านั้นที่สามารถเปลี่ยนสถานะที่ยอมรับได้",
    "\"%1$s\" shared \"%3$s\" with you (on behalf of \"%2$s\")" : "\"%1$s\" ได้แชร์ \"%3$s\" กับคุณ (ในนามของ \"%2$s\")",
    "\"%1$s\" shared \"%3$s\" with you" : "\"%1$s\" ได้แชร์ \"%3$s\" กับคุณ",
    "\"%1$s\" invited you to view \"%3$s\" (on behalf of \"%2$s\")" : "\"%1$s\" ได้เชิญคุณให้ดู \"%3$s\" (ในนามของ \"%2$s\")",
    "\"%1$s\" invited you to view \"%3$s\"" : "\"%1$s\" ได้เชิญคุณให้ดู \"%3$s\"",
    "Accept" : "ยอมรับ",
    "Decline" : "ลดลง",
    "Automatically accept new incoming local user shares" : "ยอมรับแชร์ที่เข้ามาใหม่จากในเครื่องโดยอัตโนมัติ",
    "Allow finding you via autocomplete in share dialog. If this is disabled the full username needs to be entered." : "อนุญาตให้ค้นหาคุณผ่านกล่องข้อความอัตโนมัติ จำเป็นต้องป้อนชื่อผู้ใช้แบบเต็มหากส่วนนี้ถูกปิดใช้งาน",
    "This share is password-protected" : "นี้แชร์การป้องกันด้วยรหัสผ่าน",
    "The password is wrong. Try again." : "รหัสผ่านที่ไม่ถูกต้อง กรุณาลองอีกครั้ง",
    "Password" : "รหัสผ่าน",
    "No entries found in this folder" : "ไม่พบรายการในโฟลเดอร์นี้",
    "Name" : "ชื่อ",
    "State" : "สถานะ",
    "Share time" : "แชร์เวลา",
    "Expiration date" : "วันที่หมดอายุ",
    "Sorry, this link doesn’t seem to work anymore." : "ขออภัยลิงก์นี้ดูเหมือนจะไม่ทำงานอีกต่อไป",
    "Reasons might be:" : "เหตุผลอาจจะ:",
    "the item was removed" : "รายการที่ถูกลบออก",
    "the link expired" : "ลิงก์หมดอายุ",
    "sharing is disabled" : "การแชร์ถูกปิดใช้งาน",
    "For more info, please ask the person who sent this link." : "สำหรับข้อมูลเพิ่มเติมกรุณาสอบถามผู้ที่ส่งลิงก์นี้",
    "%s is publicly shared" : "%s ได้ถูกแชร์สู่สาธารณะแล้ว",
    "Download" : "ดาวน์โหลด",
    "Download %s" : "ดาวน์โหลด %s",
    "Direct link" : "ลิงก์โดยตรง",
    "Nothing to configure." : "ไม่มีการกำหนดค่า",
    "Group Sharing Blacklist" : "แชร์กลุ่มบัญชีดำ",
    "Exclude groups from receiving shares" : "ยกเว้นกลุ่มจากการแชร์",
    "These groups will not be available to share with. Members of the group are not restricted in initiating shares and can receive shares with other groups they are a member of as usual." : "กลุ่มเหล่านี้จะไม่สามารถแชร์กับสมาชิกของกลุ่มที่ถูกจำกัดไว้ แต่สามารถแชร์กับกลุ่มอื่นๆที่เป็นสมาชิกได้ตามปกติ"
},
"nplurals=1; plural=0;");
